from gamesaver.src import search_deals
import click, sys


@click.group()
@click.version_option("0.1.0")
def main(**kwargs) -> int:
    """Find the best deals on PC games from the terminal"""
    return 0


@main.command()
@click.option(
    "--title",
    "-t",
    "title",
    required=False,
    type=str,
    help="Search deals for a specific game title",
)
@click.option(
    "--store",
    "-s",
    "store",
    required=False,
    type=str,
    help="Search all deals from a specific store",
)
def search(**kwargs):
    """Search for all deals."""
    search_deals(kwargs.get("title"), kwargs.get("store"))


if __name__ == "__main__":
    args = sys.argv
    sys.exit(main())



from .config import deals_uri
from .util import get_store
from .output import Table
from rich.progress import Progress
import requests


def search_deals(user_title: str, user_store: str) -> None:
    output = Table(show_header=True, header_style="bold magenta")

    req = requests.get(deals_uri)
    res = req.json()
    data = sorted(res, key=lambda k: k["title"])

    with Progress() as progress:
        task = progress.add_task("Finding Deals", total=len(data))
        for obj in data:
            progress.update(task, advance=1)
            title = obj["title"]
            if user_title != None and user_title.lower() != title.lower():
                continue
            store = get_store(obj["storeID"])
            if user_store != None and user_store.lower() != store.lower():
                continue
            output.table.add_row(title, store, obj["normalPrice"], obj["salePrice"])

    output.print()



from .config import stores_uri
import requests


def get_store(id: int) -> str:
    store = ""
    req = requests.get(stores_uri)
    res = req.json()
    for obj in res:
        if id == obj["storeID"]:
            store = obj["storeName"]

    return store



from setuptools import setup, find_packages
from io import open
from os import path

import pathlib

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# automatically captured required modules for install_requires in requirements.txt
with open(path.join(HERE, "requirements.txt"), encoding="utf-8") as f:
    all_reqs = f.read().split("\n")

install_requires = [
    x.strip()
    for x in all_reqs
    if ("git+" not in x) and (not x.startswith("#")) and (not x.startswith("-"))
]
dependency_links = [x.strip().replace("git+", "") for x in all_reqs if "git+" not in x]
setup(
    name="gamesaver",
    description="A simple cli tool for finding best deals on pc games",
    version="1.0.0",
    packages=find_packages(),  # list of all packages
    install_requires=install_requires,
    python_requires=">=3.7",  # any python greater than 3.7
    entry_points="""
        [console_scripts]
        gamesaver=gamesaver.__main__:main
    """,
    author="Michael Navarro",
    keyword="pc, games, cli, save, money",
    long_description=README,
    long_description_content_type="text/markdown",
    license="MIT",
    url="https://github.com/michaelnavs/gamesaver",
    download_url="https://github.com/michaelnavs/gamesaver/archive/1.0.0.tar.gz",
    dependency_links=dependency_links,
    author_email="michaelnavs@gmail.com",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
)



from rich import table
from rich.console import Console


class Table:
    def __init__(self, header_style: str, show_header: bool = True):
        self.console = Console()
        self.table = table.Table(header_style=header_style, show_header=show_header)
        self.table.add_column("Title")
        self.table.add_column("Store", style="cyan")
        self.table.add_column("Original Price", style="red")
        self.table.add_column("Sale Price", style="green")

    def print(self) -> None:
        self.console.print(self.table)
